# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class BadgeCampaignsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def badge_applications_get_all(self, **kwargs):  # noqa: E501
        """[BETA] Get a list of badge applications  # noqa: E501

        Use this resource to get a list of badge applications. <a href=\"/badge/#4\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.badge_applications_get_all(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str campaign_id: Campaign ID.
        :param str offer_id: Offer ID.
        :param int offset: Offset.
        :param int limit: The maximum number of applications returned in the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BadgeApplications
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.badge_applications_get_all_with_http_info(**kwargs)  # noqa: E501

    def badge_applications_get_all_with_http_info(self, **kwargs):  # noqa: E501
        """[BETA] Get a list of badge applications  # noqa: E501

        Use this resource to get a list of badge applications. <a href=\"/badge/#4\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.badge_applications_get_all_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str campaign_id: Campaign ID.
        :param str offer_id: Offer ID.
        :param int offset: Offset.
        :param int limit: The maximum number of applications returned in the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BadgeApplications, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['campaign_id', 'offer_id', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method badge_applications_get_all" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `badge_applications_get_all`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `badge_applications_get_all`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'campaign_id' in local_var_params and local_var_params['campaign_id'] is not None:  # noqa: E501
            query_params.append(('campaign.id', local_var_params['campaign_id']))  # noqa: E501
        if 'offer_id' in local_var_params and local_var_params['offer_id'] is not None:  # noqa: E501
            query_params.append(('offer.id', local_var_params['offer_id']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/badge-applications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BadgeApplications',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def badge_applications_get_one(self, application_id, **kwargs):  # noqa: E501
        """[BETA] Get a badge application details  # noqa: E501

        Use this resource to get a badge application details. <a href=\"/badge/#3\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.badge_applications_get_one(application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str application_id: Badge application ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BadgeApplication
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.badge_applications_get_one_with_http_info(application_id, **kwargs)  # noqa: E501

    def badge_applications_get_one_with_http_info(self, application_id, **kwargs):  # noqa: E501
        """[BETA] Get a badge application details  # noqa: E501

        Use this resource to get a badge application details. <a href=\"/badge/#3\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.badge_applications_get_one_with_http_info(application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str application_id: Badge application ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BadgeApplication, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['application_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method badge_applications_get_one" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'application_id' is set
        if self.api_client.client_side_validation and ('application_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['application_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_id` when calling `badge_applications_get_one`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application_id' in local_var_params:
            path_params['applicationId'] = local_var_params['application_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/badge-applications/{applicationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BadgeApplication',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def badge_campaigns_get_all(self, **kwargs):  # noqa: E501
        """[BETA] Get a list of available badge campaigns  # noqa: E501

        Badge campaigns are another way to promote your offers. You can apply for a badge, which - depending on a type - will be displayed on your offer page of on the list of offers. First - use this resource to get a list of all available badge campaigns at the moment, then use *POST /sale/badges* to apply for badge. <a href=\"/badge/#1\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.badge_campaigns_get_all(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetBadgeCampaignsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.badge_campaigns_get_all_with_http_info(**kwargs)  # noqa: E501

    def badge_campaigns_get_all_with_http_info(self, **kwargs):  # noqa: E501
        """[BETA] Get a list of available badge campaigns  # noqa: E501

        Badge campaigns are another way to promote your offers. You can apply for a badge, which - depending on a type - will be displayed on your offer page of on the list of offers. First - use this resource to get a list of all available badge campaigns at the moment, then use *POST /sale/badges* to apply for badge. <a href=\"/badge/#1\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.badge_campaigns_get_all_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetBadgeCampaignsList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method badge_campaigns_get_all" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/badge-campaigns', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetBadgeCampaignsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_badges(self, **kwargs):  # noqa: E501
        """[BETA] Get a list of badges  # noqa: E501

        Use this resource to get a list of badges in authorized seller's offers. <a href=\"/badge/#5\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_badges(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer ID.
        :param int offset: Offset.
        :param int limit: The maximum number of badges returned in the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BadgesList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_badges_with_http_info(**kwargs)  # noqa: E501

    def get_badges_with_http_info(self, **kwargs):  # noqa: E501
        """[BETA] Get a list of badges  # noqa: E501

        Use this resource to get a list of badges in authorized seller's offers. <a href=\"/badge/#5\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_badges_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer ID.
        :param int offset: Offset.
        :param int limit: The maximum number of badges returned in the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BadgesList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_badges" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_badges`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_badges`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offer_id' in local_var_params and local_var_params['offer_id'] is not None:  # noqa: E501
            query_params.append(('offer.id', local_var_params['offer_id']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/badges', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BadgesList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_badges(self, **kwargs):  # noqa: E501
        """[BETA] Apply for badge in selected offer  # noqa: E501

        This resource allows you to apply for a badge. Most badges involve additional fee charged. Your badge application will be verified and you will be notified about the verification status via e-mail. You can use *Location* provided in header of the response to track your application status. Application will be removed after 30 days when status of the application was changed form PROCESSED or DECLINED. Fees will be charged in accordance with Annex No. 1 to the   <a href=\"https://allegro.pl/regulaminy/regulamin-strefy-okazji-9dGVAPB69In\"     target=\"_blank\">Daily deals zone terms and conditions</a>.  By using this resource you agree to the   <a href=\"https://allegro.pl/regulaminy/regulamin-strefy-okazji-9dGVAPB69In\"     target=\"_blank\">Daily deals zone terms and conditions</a> or   <a href=\"https://allegro.pl/regulaminy/regulamin-programu-bonusowego-prowizja-nawet-0-5-0KPkAE7wkcv\"     target=\"_blank\">Commission discount terms and conditions</a>. <a href=\"/badge/#2\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_badges(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BadgeApplicationRequest badge_application_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BadgeApplication
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.post_badges_with_http_info(**kwargs)  # noqa: E501

    def post_badges_with_http_info(self, **kwargs):  # noqa: E501
        """[BETA] Apply for badge in selected offer  # noqa: E501

        This resource allows you to apply for a badge. Most badges involve additional fee charged. Your badge application will be verified and you will be notified about the verification status via e-mail. You can use *Location* provided in header of the response to track your application status. Application will be removed after 30 days when status of the application was changed form PROCESSED or DECLINED. Fees will be charged in accordance with Annex No. 1 to the   <a href=\"https://allegro.pl/regulaminy/regulamin-strefy-okazji-9dGVAPB69In\"     target=\"_blank\">Daily deals zone terms and conditions</a>.  By using this resource you agree to the   <a href=\"https://allegro.pl/regulaminy/regulamin-strefy-okazji-9dGVAPB69In\"     target=\"_blank\">Daily deals zone terms and conditions</a> or   <a href=\"https://allegro.pl/regulaminy/regulamin-programu-bonusowego-prowizja-nawet-0-5-0KPkAE7wkcv\"     target=\"_blank\">Commission discount terms and conditions</a>. <a href=\"/badge/#2\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_badges_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BadgeApplicationRequest badge_application_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BadgeApplication, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['badge_application_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_badges" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'badge_application_request' in local_var_params:
            body_params = local_var_params['badge_application_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/badges', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BadgeApplication',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SizeTablesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_table_using_get(self, table_id, **kwargs):  # noqa: E501
        """Get a size table details  # noqa: E501

        Use this resource to get selected size table. <a href=\"../../news/2018-04-19-news_tabele_rozmiarow/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_table_using_get(table_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str table_id: Table identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PublicTableDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_table_using_get_with_http_info(table_id, **kwargs)  # noqa: E501

    def get_table_using_get_with_http_info(self, table_id, **kwargs):  # noqa: E501
        """Get a size table details  # noqa: E501

        Use this resource to get selected size table. <a href=\"../../news/2018-04-19-news_tabele_rozmiarow/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_table_using_get_with_http_info(table_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str table_id: Table identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PublicTableDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['table_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_table_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'table_id' is set
        if self.api_client.client_side_validation and ('table_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['table_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id` when calling `get_table_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'table_id' in local_var_params:
            path_params['tableId'] = local_var_params['table_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/size-tables/{tableId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PublicTableDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tables_using_get(self, user_id, **kwargs):  # noqa: E501
        """Get the user's size tables  # noqa: E501

        Use this resource to get all size tables assigned to a seller account. <a href=\"../../news/2018-04-19-news_tabele_rozmiarow/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tables_using_get(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: User identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PublicTablesDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_tables_using_get_with_http_info(user_id, **kwargs)  # noqa: E501

    def get_tables_using_get_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Get the user's size tables  # noqa: E501

        Use this resource to get all size tables assigned to a seller account. <a href=\"../../news/2018-04-19-news_tabele_rozmiarow/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tables_using_get_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: User identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PublicTablesDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tables_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_id` when calling `get_tables_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user.id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/size-tables', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PublicTablesDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ProposeSaleProductRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'category': 'Category',
        'eans': 'list[str]',
        'images': 'list[ImageUrl]',
        'parameters': 'list[ProductParameter]',
        'description': 'StandardizedDescription'
    }

    attribute_map = {
        'name': 'name',
        'category': 'category',
        'eans': 'eans',
        'images': 'images',
        'parameters': 'parameters',
        'description': 'description'
    }

    def __init__(self, name=None, category=None, eans=None, images=None, parameters=None, description=None, local_vars_configuration=None):  # noqa: E501
        """ProposeSaleProductRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._category = None
        self._eans = None
        self._images = None
        self._parameters = None
        self._description = None
        self.discriminator = None

        self.name = name
        self.category = category
        if eans is not None:
            self.eans = eans
        self.images = images
        self.parameters = parameters
        if description is not None:
            self.description = description

    @property
    def name(self):
        """Gets the name of this ProposeSaleProductRequest.  # noqa: E501

        Suggested product name.  # noqa: E501

        :return: The name of this ProposeSaleProductRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProposeSaleProductRequest.

        Suggested product name.  # noqa: E501

        :param name: The name of this ProposeSaleProductRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 50):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")  # noqa: E501

        self._name = name

    @property
    def category(self):
        """Gets the category of this ProposeSaleProductRequest.  # noqa: E501


        :return: The category of this ProposeSaleProductRequest.  # noqa: E501
        :rtype: Category
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ProposeSaleProductRequest.


        :param category: The category of this ProposeSaleProductRequest.  # noqa: E501
        :type: Category
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def eans(self):
        """Gets the eans of this ProposeSaleProductRequest.  # noqa: E501

        A list of codes that identify this product. Currently this can include EAN, ISBN, and UPC identifier types.  # noqa: E501

        :return: The eans of this ProposeSaleProductRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._eans

    @eans.setter
    def eans(self, eans):
        """Sets the eans of this ProposeSaleProductRequest.

        A list of codes that identify this product. Currently this can include EAN, ISBN, and UPC identifier types.  # noqa: E501

        :param eans: The eans of this ProposeSaleProductRequest.  # noqa: E501
        :type: list[str]
        """

        self._eans = eans

    @property
    def images(self):
        """Gets the images of this ProposeSaleProductRequest.  # noqa: E501

        List of product images. At least one image is required.  # noqa: E501

        :return: The images of this ProposeSaleProductRequest.  # noqa: E501
        :rtype: list[ImageUrl]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this ProposeSaleProductRequest.

        List of product images. At least one image is required.  # noqa: E501

        :param images: The images of this ProposeSaleProductRequest.  # noqa: E501
        :type: list[ImageUrl]
        """
        if self.local_vars_configuration.client_side_validation and images is None:  # noqa: E501
            raise ValueError("Invalid value for `images`, must not be `None`")  # noqa: E501

        self._images = images

    @property
    def parameters(self):
        """Gets the parameters of this ProposeSaleProductRequest.  # noqa: E501

        List of product parameters.  # noqa: E501

        :return: The parameters of this ProposeSaleProductRequest.  # noqa: E501
        :rtype: list[ProductParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this ProposeSaleProductRequest.

        List of product parameters.  # noqa: E501

        :param parameters: The parameters of this ProposeSaleProductRequest.  # noqa: E501
        :type: list[ProductParameter]
        """
        if self.local_vars_configuration.client_side_validation and parameters is None:  # noqa: E501
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    @property
    def description(self):
        """Gets the description of this ProposeSaleProductRequest.  # noqa: E501


        :return: The description of this ProposeSaleProductRequest.  # noqa: E501
        :rtype: StandardizedDescription
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProposeSaleProductRequest.


        :param description: The description of this ProposeSaleProductRequest.  # noqa: E501
        :type: StandardizedDescription
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProposeSaleProductRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProposeSaleProductRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.listing_response import ListingResponse  # noqa: E501
from allegro_api.rest import ApiException

class TestListingResponse(unittest.TestCase):
    """ListingResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListingResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.listing_response.ListingResponse()  # noqa: E501
        if include_optional :
            return ListingResponse(
                items = allegro_api.models.listing_response_offers.ListingResponseOffers(
                    promoted = [
                        allegro_api.models.listing_offer.ListingOffer(
                            id = '2865624934', 
                            name = 'Buty damskie adidas', 
                            seller = allegro_api.models.offer_seller.OfferSeller(
                                id = '41846511', 
                                company = True, 
                                super_seller = True, ), 
                            promotion = allegro_api.models.offer_promotion.OfferPromotion(
                                emphasized = True, 
                                bold = True, 
                                highlight = True, ), 
                            delivery = allegro_api.models.offer_delivery.OfferDelivery(
                                available_for_free = True, 
                                lowest_price = allegro_api.models.offer_lowest_price.OfferLowestPrice(
                                    amount = '123.45', 
                                    currency = 'PLN', ), ), 
                            images = [
                                allegro_api.models.offer_images.OfferImages(
                                    url = 'https://a.allegroimg.com/original/0129e7/f15ce8924166850eec3fb82bcd5s/BUTY-ADIDAS-DAMSKIE', )
                                ], 
                            selling_mode = allegro_api.models.offer_selling_mode.OfferSellingMode(
                                format = 'BUY_NOW', 
                                price = allegro_api.models.offer_price.OfferPrice(
                                    amount = '123.45', 
                                    currency = 'PLN', ), 
                                fixed_price = allegro_api.models.offer_fixed_price.OfferFixedPrice(
                                    amount = '123.45', 
                                    currency = 'PLN', ), 
                                popularity = 38, 
                                bid_count = 12, ), 
                            stock = allegro_api.models.offer_stock.OfferStock(
                                unit = 'UNIT', 
                                available = 23, ), 
                            vendor = allegro_api.models.offer_vendor.OfferVendor(
                                id = 'CHARYTATYWNI_ALLEGRO', 
                                url = 'http://charytatywni.allegro.pl/oferta-charytatywna-i1234567', ), 
                            category = allegro_api.models.offer_category.OfferCategory(
                                id = '257929', ), 
                            publication = allegro_api.models.offer_publication.OfferPublication(
                                ending_at = '2019-05-15T18:09:41.000Z', ), )
                        ], 
                    regular = [
                        allegro_api.models.listing_offer.ListingOffer(
                            id = '2865624934', 
                            name = 'Buty damskie adidas', )
                        ], ), 
                categories = allegro_api.models.listing_response_categories.ListingResponseCategories(
                    subcategories = [
                        allegro_api.models.listing_category_with_count.ListingCategoryWithCount(
                            id = '257929', 
                            name = 'Sportowe', 
                            count = 123, )
                        ], 
                    path = [
                        allegro_api.models.listing_category.ListingCategory(
                            id = '257929', 
                            name = 'Sportowe', )
                        ], ), 
                filters = [
                    allegro_api.models.listing_response_filters.ListingResponseFilters(
                        id = 'campaign', 
                        type = 'MULTI', 
                        name = 'kampania', 
                        values = [
                            allegro_api.models.listing_response_filters_values.ListingResponseFiltersValues(
                                name = 'raty zero', 
                                value = 'INSTALLMENTS_ZERO', 
                                id_suffix = '.to', 
                                count = 123, 
                                selected = True, )
                            ], 
                        min_value = 0, 
                        max_value = 1000, 
                        unit = 'zł', )
                    ], 
                search_meta = allegro_api.models.listing_response_search_meta.ListingResponseSearchMeta(
                    available_count = 6000, 
                    total_count = 319203, 
                    fallback = True, ), 
                sort = [
                    allegro_api.models.listing_response_sort.ListingResponseSort(
                        value = '-relevance', 
                        name = 'trafność', 
                        order = 'największa', 
                        selected = True, )
                    ]
            )
        else :
            return ListingResponse(
        )

    def testListingResponse(self):
        """Test ListingResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CheckoutFormAddWaybillRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'carrier_id': 'str',
        'waybill': 'str',
        'carrier_name': 'str',
        'line_items': 'list[object]'
    }

    attribute_map = {
        'carrier_id': 'carrierId',
        'waybill': 'waybill',
        'carrier_name': 'carrierName',
        'line_items': 'lineItems'
    }

    def __init__(self, carrier_id=None, waybill=None, carrier_name=None, line_items=None, local_vars_configuration=None):  # noqa: E501
        """CheckoutFormAddWaybillRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._carrier_id = None
        self._waybill = None
        self._carrier_name = None
        self._line_items = None
        self.discriminator = None

        self.carrier_id = carrier_id
        self.waybill = waybill
        if carrier_name is not None:
            self.carrier_name = carrier_name
        self.line_items = line_items

    @property
    def carrier_id(self):
        """Gets the carrier_id of this CheckoutFormAddWaybillRequest.  # noqa: E501

        Supported carriers:   * Polish carriers: `UPS`, `INPOST`, `DHL`, `GLS`, `RUCH`, `POCZTA_POLSKA`, `DPD`, `FEDEX`, `TNT_EXPRESS`, `DB_SCHENKER`, `RABEN`, `GEIS`, `DTS`, `PEKAES`, `PATRON`, `X_PRESS_COURIERS`, `RHENUS_LOGISTICS`   * International carriers: `YUN_EXPRESS`, `CHINA_POST`   * Other: `OTHER`  Carrier identifier taken from the dictionary below. It’s highly recommended to use an identifier different from `OTHER`, because its parcel status may be updated automatically. Carrier identifier `OTHER` is reserved for cases when seller uses a custom carrier or not yet integrated with Allegro.  # noqa: E501

        :return: The carrier_id of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :rtype: str
        """
        return self._carrier_id

    @carrier_id.setter
    def carrier_id(self, carrier_id):
        """Sets the carrier_id of this CheckoutFormAddWaybillRequest.

        Supported carriers:   * Polish carriers: `UPS`, `INPOST`, `DHL`, `GLS`, `RUCH`, `POCZTA_POLSKA`, `DPD`, `FEDEX`, `TNT_EXPRESS`, `DB_SCHENKER`, `RABEN`, `GEIS`, `DTS`, `PEKAES`, `PATRON`, `X_PRESS_COURIERS`, `RHENUS_LOGISTICS`   * International carriers: `YUN_EXPRESS`, `CHINA_POST`   * Other: `OTHER`  Carrier identifier taken from the dictionary below. It’s highly recommended to use an identifier different from `OTHER`, because its parcel status may be updated automatically. Carrier identifier `OTHER` is reserved for cases when seller uses a custom carrier or not yet integrated with Allegro.  # noqa: E501

        :param carrier_id: The carrier_id of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and carrier_id is None:  # noqa: E501
            raise ValueError("Invalid value for `carrier_id`, must not be `None`")  # noqa: E501

        self._carrier_id = carrier_id

    @property
    def waybill(self):
        """Gets the waybill of this CheckoutFormAddWaybillRequest.  # noqa: E501

        Waybill number (parcel tracking number). Cannot be empty and must be no longer than 64 characters. It can contain any word character (equal to [a-zA-Z0-9_]) and special characters: parentheses and hyphen-minus.  # noqa: E501

        :return: The waybill of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :rtype: str
        """
        return self._waybill

    @waybill.setter
    def waybill(self, waybill):
        """Sets the waybill of this CheckoutFormAddWaybillRequest.

        Waybill number (parcel tracking number). Cannot be empty and must be no longer than 64 characters. It can contain any word character (equal to [a-zA-Z0-9_]) and special characters: parentheses and hyphen-minus.  # noqa: E501

        :param waybill: The waybill of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and waybill is None:  # noqa: E501
            raise ValueError("Invalid value for `waybill`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                waybill is not None and len(waybill) > 64):
            raise ValueError("Invalid value for `waybill`, length must be less than or equal to `64`")  # noqa: E501

        self._waybill = waybill

    @property
    def carrier_name(self):
        """Gets the carrier_name of this CheckoutFormAddWaybillRequest.  # noqa: E501

        Carrier name to be provided only if carrierId is OTHER, otherwise it’s ignored. Must be no longer than 30 characters.  # noqa: E501

        :return: The carrier_name of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :rtype: str
        """
        return self._carrier_name

    @carrier_name.setter
    def carrier_name(self, carrier_name):
        """Sets the carrier_name of this CheckoutFormAddWaybillRequest.

        Carrier name to be provided only if carrierId is OTHER, otherwise it’s ignored. Must be no longer than 30 characters.  # noqa: E501

        :param carrier_name: The carrier_name of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                carrier_name is not None and len(carrier_name) > 30):
            raise ValueError("Invalid value for `carrier_name`, length must be less than or equal to `30`")  # noqa: E501

        self._carrier_name = carrier_name

    @property
    def line_items(self):
        """Gets the line_items of this CheckoutFormAddWaybillRequest.  # noqa: E501

        List of order line items. They must be from the order specified in the path parameter. List cannot be empty.  # noqa: E501

        :return: The line_items of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :rtype: list[object]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this CheckoutFormAddWaybillRequest.

        List of order line items. They must be from the order specified in the path parameter. List cannot be empty.  # noqa: E501

        :param line_items: The line_items of this CheckoutFormAddWaybillRequest.  # noqa: E501
        :type: list[object]
        """
        if self.local_vars_configuration.client_side_validation and line_items is None:  # noqa: E501
            raise ValueError("Invalid value for `line_items`, must not be `None`")  # noqa: E501

        self._line_items = line_items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckoutFormAddWaybillRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckoutFormAddWaybillRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.order import Order  # noqa: E501
from allegro_api.rest import ApiException

class TestOrder(unittest.TestCase):
    """Order unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Order
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.order.Order()  # noqa: E501
        if include_optional :
            return Order(
                id = '0', 
                offers = [
                    allegro_api.models.offer.Offer(
                        additional_services = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                            implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                            return_policy = allegro_api.models.return_policy.ReturnPolicy(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                            warranty = allegro_api.models.warranty.Warranty(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                        attachments = [
                            allegro_api.models.attachment.Attachment(
                                id = '1928302_MANUAL_45d7a0f543e1b0d05e12a1aef5642efe63389a1d419fe9286d0f158044391fdce', )
                            ], 
                        category = allegro_api.models.category.Category(
                            id = '0', ), 
                        compatibility_list = allegro_api.models.compatibility_list.CompatibilityList(), 
                        contact = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        delivery = allegro_api.models.delivery.Delivery(
                            additional_info = '0', 
                            handling_time = 'PDT12H30M5S', 
                            shipment_date = '2018-04-01T08:00Z', 
                            shipping_rates = allegro_api.models.just_id.JustId(
                                id = '0', ), ), 
                        description = allegro_api.models.standardized_description.StandardizedDescription(
                            sections = [
                                allegro_api.models.description_section.DescriptionSection(
                                    items = [
                                        allegro_api.models.description_section_item.DescriptionSectionItem(
                                            type = '0', )
                                        ], )
                                ], ), 
                        ean = '0', 
                        external = allegro_api.models.external_id.ExternalId(
                            id = 'AH-129834', ), 
                        id = '0', 
                        images = [
                            allegro_api.models.image_url.ImageUrl(
                                url = '0', )
                            ], 
                        location = allegro_api.models.location.Location(
                            city = '0', 
                            country_code = '0', 
                            post_code = '0', 
                            province = '0', ), 
                        name = '0', 
                        parameters = [
                            allegro_api.models.parameter.Parameter(
                                id = '0', 
                                range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                    from = '0', 
                                    to = '0', ), 
                                values = [
                                    '0'
                                    ], 
                                values_ids = [
                                    '0'
                                    ], )
                            ], 
                        payments = allegro_api.models.payments.Payments(
                            invoice = '0', ), 
                        product = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        promotion = allegro_api.models.promotion.Promotion(
                            bold = True, 
                            department_page = True, 
                            emphasized = True, 
                            emphasized_highlight_bold_package = True, 
                            highlight = True, ), 
                        publication = allegro_api.models.publication.Publication(
                            duration = 'PDT12H30M5S', 
                            ending_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            starting_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            status = 'INACTIVE', 
                            ended_by = 'USER', 
                            republish = False, ), 
                        selling_mode = allegro_api.models.selling_mode.SellingMode(
                            format = 'BUY_NOW', 
                            price = null, 
                            minimal_price = null, 
                            starting_price = null, ), 
                        size_table = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        stock = allegro_api.models.stock.Stock(
                            available = 56, 
                            unit = '0', ), 
                        tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                            id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', ), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        validation = allegro_api.models.validation.Validation(
                            errors = [
                                allegro_api.models.validation_error.ValidationError(
                                    code = '0', 
                                    details = '0', 
                                    message = '0', 
                                    path = '0', 
                                    user_message = '0', )
                                ], 
                            validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ]
            )
        else :
            return Order(
                id = '0',
                offers = [
                    allegro_api.models.offer.Offer(
                        additional_services = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                            implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                            return_policy = allegro_api.models.return_policy.ReturnPolicy(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                            warranty = allegro_api.models.warranty.Warranty(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                        attachments = [
                            allegro_api.models.attachment.Attachment(
                                id = '1928302_MANUAL_45d7a0f543e1b0d05e12a1aef5642efe63389a1d419fe9286d0f158044391fdce', )
                            ], 
                        category = allegro_api.models.category.Category(
                            id = '0', ), 
                        compatibility_list = allegro_api.models.compatibility_list.CompatibilityList(), 
                        contact = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        delivery = allegro_api.models.delivery.Delivery(
                            additional_info = '0', 
                            handling_time = 'PDT12H30M5S', 
                            shipment_date = '2018-04-01T08:00Z', 
                            shipping_rates = allegro_api.models.just_id.JustId(
                                id = '0', ), ), 
                        description = allegro_api.models.standardized_description.StandardizedDescription(
                            sections = [
                                allegro_api.models.description_section.DescriptionSection(
                                    items = [
                                        allegro_api.models.description_section_item.DescriptionSectionItem(
                                            type = '0', )
                                        ], )
                                ], ), 
                        ean = '0', 
                        external = allegro_api.models.external_id.ExternalId(
                            id = 'AH-129834', ), 
                        id = '0', 
                        images = [
                            allegro_api.models.image_url.ImageUrl(
                                url = '0', )
                            ], 
                        location = allegro_api.models.location.Location(
                            city = '0', 
                            country_code = '0', 
                            post_code = '0', 
                            province = '0', ), 
                        name = '0', 
                        parameters = [
                            allegro_api.models.parameter.Parameter(
                                id = '0', 
                                range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                    from = '0', 
                                    to = '0', ), 
                                values = [
                                    '0'
                                    ], 
                                values_ids = [
                                    '0'
                                    ], )
                            ], 
                        payments = allegro_api.models.payments.Payments(
                            invoice = '0', ), 
                        product = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        promotion = allegro_api.models.promotion.Promotion(
                            bold = True, 
                            department_page = True, 
                            emphasized = True, 
                            emphasized_highlight_bold_package = True, 
                            highlight = True, ), 
                        publication = allegro_api.models.publication.Publication(
                            duration = 'PDT12H30M5S', 
                            ending_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            starting_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            status = 'INACTIVE', 
                            ended_by = 'USER', 
                            republish = False, ), 
                        selling_mode = allegro_api.models.selling_mode.SellingMode(
                            format = 'BUY_NOW', 
                            price = null, 
                            minimal_price = null, 
                            starting_price = null, ), 
                        size_table = allegro_api.models.just_id.JustId(
                            id = '0', ), 
                        stock = allegro_api.models.stock.Stock(
                            available = 56, 
                            unit = '0', ), 
                        tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                            id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', ), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        validation = allegro_api.models.validation.Validation(
                            errors = [
                                allegro_api.models.validation_error.ValidationError(
                                    code = '0', 
                                    details = '0', 
                                    message = '0', 
                                    path = '0', 
                                    user_message = '0', )
                                ], 
                            validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
        )

    def testOrder(self):
        """Test Order"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class UserRating(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'answer': 'Answer',
        'buyer': 'User',
        'comment': 'str',
        'created_at': 'datetime',
        'excluded_from_average_rates': 'bool',
        'id': 'str',
        'order': 'Order',
        'rates': 'Rates',
        'recommended': 'bool',
        'removal': 'Removal'
    }

    attribute_map = {
        'answer': 'answer',
        'buyer': 'buyer',
        'comment': 'comment',
        'created_at': 'createdAt',
        'excluded_from_average_rates': 'excludedFromAverageRates',
        'id': 'id',
        'order': 'order',
        'rates': 'rates',
        'recommended': 'recommended',
        'removal': 'removal'
    }

    def __init__(self, answer=None, buyer=None, comment=None, created_at=None, excluded_from_average_rates=None, id=None, order=None, rates=None, recommended=None, removal=None, local_vars_configuration=None):  # noqa: E501
        """UserRating - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._answer = None
        self._buyer = None
        self._comment = None
        self._created_at = None
        self._excluded_from_average_rates = None
        self._id = None
        self._order = None
        self._rates = None
        self._recommended = None
        self._removal = None
        self.discriminator = None

        if answer is not None:
            self.answer = answer
        self.buyer = buyer
        self.comment = comment
        self.created_at = created_at
        if excluded_from_average_rates is not None:
            self.excluded_from_average_rates = excluded_from_average_rates
        self.id = id
        if order is not None:
            self.order = order
        if rates is not None:
            self.rates = rates
        self.recommended = recommended
        if removal is not None:
            self.removal = removal

    @property
    def answer(self):
        """Gets the answer of this UserRating.  # noqa: E501


        :return: The answer of this UserRating.  # noqa: E501
        :rtype: Answer
        """
        return self._answer

    @answer.setter
    def answer(self, answer):
        """Sets the answer of this UserRating.


        :param answer: The answer of this UserRating.  # noqa: E501
        :type: Answer
        """

        self._answer = answer

    @property
    def buyer(self):
        """Gets the buyer of this UserRating.  # noqa: E501


        :return: The buyer of this UserRating.  # noqa: E501
        :rtype: User
        """
        return self._buyer

    @buyer.setter
    def buyer(self, buyer):
        """Sets the buyer of this UserRating.


        :param buyer: The buyer of this UserRating.  # noqa: E501
        :type: User
        """
        if self.local_vars_configuration.client_side_validation and buyer is None:  # noqa: E501
            raise ValueError("Invalid value for `buyer`, must not be `None`")  # noqa: E501

        self._buyer = buyer

    @property
    def comment(self):
        """Gets the comment of this UserRating.  # noqa: E501

        Buyer's text comment  # noqa: E501

        :return: The comment of this UserRating.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UserRating.

        Buyer's text comment  # noqa: E501

        :param comment: The comment of this UserRating.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and comment is None:  # noqa: E501
            raise ValueError("Invalid value for `comment`, must not be `None`")  # noqa: E501

        self._comment = comment

    @property
    def created_at(self):
        """Gets the created_at of this UserRating.  # noqa: E501

        Creation datetime in ISO 8601 format  # noqa: E501

        :return: The created_at of this UserRating.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this UserRating.

        Creation datetime in ISO 8601 format  # noqa: E501

        :param created_at: The created_at of this UserRating.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def excluded_from_average_rates(self):
        """Gets the excluded_from_average_rates of this UserRating.  # noqa: E501

        If true this rating was not included in calculating average user rates  # noqa: E501

        :return: The excluded_from_average_rates of this UserRating.  # noqa: E501
        :rtype: bool
        """
        return self._excluded_from_average_rates

    @excluded_from_average_rates.setter
    def excluded_from_average_rates(self, excluded_from_average_rates):
        """Sets the excluded_from_average_rates of this UserRating.

        If true this rating was not included in calculating average user rates  # noqa: E501

        :param excluded_from_average_rates: The excluded_from_average_rates of this UserRating.  # noqa: E501
        :type: bool
        """

        self._excluded_from_average_rates = excluded_from_average_rates

    @property
    def id(self):
        """Gets the id of this UserRating.  # noqa: E501

        Rating id  # noqa: E501

        :return: The id of this UserRating.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserRating.

        Rating id  # noqa: E501

        :param id: The id of this UserRating.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def order(self):
        """Gets the order of this UserRating.  # noqa: E501


        :return: The order of this UserRating.  # noqa: E501
        :rtype: Order
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this UserRating.


        :param order: The order of this UserRating.  # noqa: E501
        :type: Order
        """

        self._order = order

    @property
    def rates(self):
        """Gets the rates of this UserRating.  # noqa: E501


        :return: The rates of this UserRating.  # noqa: E501
        :rtype: Rates
        """
        return self._rates

    @rates.setter
    def rates(self, rates):
        """Sets the rates of this UserRating.


        :param rates: The rates of this UserRating.  # noqa: E501
        :type: Rates
        """

        self._rates = rates

    @property
    def recommended(self):
        """Gets the recommended of this UserRating.  # noqa: E501

        Whether buyer recommends the order  # noqa: E501

        :return: The recommended of this UserRating.  # noqa: E501
        :rtype: bool
        """
        return self._recommended

    @recommended.setter
    def recommended(self, recommended):
        """Sets the recommended of this UserRating.

        Whether buyer recommends the order  # noqa: E501

        :param recommended: The recommended of this UserRating.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and recommended is None:  # noqa: E501
            raise ValueError("Invalid value for `recommended`, must not be `None`")  # noqa: E501

        self._recommended = recommended

    @property
    def removal(self):
        """Gets the removal of this UserRating.  # noqa: E501


        :return: The removal of this UserRating.  # noqa: E501
        :rtype: Removal
        """
        return self._removal

    @removal.setter
    def removal(self, removal):
        """Sets the removal of this UserRating.


        :param removal: The removal of this UserRating.  # noqa: E501
        :type: Removal
        """

        self._removal = removal

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserRating):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserRating):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ProductParameter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'range_value': 'ParameterRangeValue',
        'values': 'list[str]',
        'values_ids': 'list[str]',
        'values_labels': 'list[str]',
        'unit': 'str',
        'options': 'list[ProductParameterOptions]'
    }

    attribute_map = {
        'id': 'id',
        'range_value': 'rangeValue',
        'values': 'values',
        'values_ids': 'valuesIds',
        'values_labels': 'valuesLabels',
        'unit': 'unit',
        'options': 'options'
    }

    def __init__(self, id=None, range_value=None, values=None, values_ids=None, values_labels=None, unit=None, options=None, local_vars_configuration=None):  # noqa: E501
        """ProductParameter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._range_value = None
        self._values = None
        self._values_ids = None
        self._values_labels = None
        self._unit = None
        self._options = None
        self.discriminator = None

        self.id = id
        if range_value is not None:
            self.range_value = range_value
        if values is not None:
            self.values = values
        if values_ids is not None:
            self.values_ids = values_ids
        if values_labels is not None:
            self.values_labels = values_labels
        if unit is not None:
            self.unit = unit
        if options is not None:
            self.options = options

    @property
    def id(self):
        """Gets the id of this ProductParameter.  # noqa: E501


        :return: The id of this ProductParameter.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductParameter.


        :param id: The id of this ProductParameter.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def range_value(self):
        """Gets the range_value of this ProductParameter.  # noqa: E501


        :return: The range_value of this ProductParameter.  # noqa: E501
        :rtype: ParameterRangeValue
        """
        return self._range_value

    @range_value.setter
    def range_value(self, range_value):
        """Sets the range_value of this ProductParameter.


        :param range_value: The range_value of this ProductParameter.  # noqa: E501
        :type: ParameterRangeValue
        """

        self._range_value = range_value

    @property
    def values(self):
        """Gets the values of this ProductParameter.  # noqa: E501


        :return: The values of this ProductParameter.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ProductParameter.


        :param values: The values of this ProductParameter.  # noqa: E501
        :type: list[str]
        """

        self._values = values

    @property
    def values_ids(self):
        """Gets the values_ids of this ProductParameter.  # noqa: E501


        :return: The values_ids of this ProductParameter.  # noqa: E501
        :rtype: list[str]
        """
        return self._values_ids

    @values_ids.setter
    def values_ids(self, values_ids):
        """Sets the values_ids of this ProductParameter.


        :param values_ids: The values_ids of this ProductParameter.  # noqa: E501
        :type: list[str]
        """

        self._values_ids = values_ids

    @property
    def values_labels(self):
        """Gets the values_labels of this ProductParameter.  # noqa: E501


        :return: The values_labels of this ProductParameter.  # noqa: E501
        :rtype: list[str]
        """
        return self._values_labels

    @values_labels.setter
    def values_labels(self, values_labels):
        """Sets the values_labels of this ProductParameter.


        :param values_labels: The values_labels of this ProductParameter.  # noqa: E501
        :type: list[str]
        """

        self._values_labels = values_labels

    @property
    def unit(self):
        """Gets the unit of this ProductParameter.  # noqa: E501


        :return: The unit of this ProductParameter.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this ProductParameter.


        :param unit: The unit of this ProductParameter.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def options(self):
        """Gets the options of this ProductParameter.  # noqa: E501


        :return: The options of this ProductParameter.  # noqa: E501
        :rtype: list[ProductParameterOptions]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this ProductParameter.


        :param options: The options of this ProductParameter.  # noqa: E501
        :type: list[ProductParameterOptions]
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductParameter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProductParameter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.badge_application_request import BadgeApplicationRequest  # noqa: E501
from allegro_api.rest import ApiException

class TestBadgeApplicationRequest(unittest.TestCase):
    """BadgeApplicationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BadgeApplicationRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.badge_application_request.BadgeApplicationRequest()  # noqa: E501
        if include_optional :
            return BadgeApplicationRequest(
                campaign = allegro_api.models.badge_application_campaign.BadgeApplicationCampaign(
                    id = 'BARGAIN', ), 
                offer = allegro_api.models.badge_offer.BadgeOffer(
                    id = '987654321', ), 
                prices = allegro_api.models.badge_prices.BadgePrices(
                    market = allegro_api.models.badge_application_market_price.BadgeApplicationMarketPrice(
                        amount = '1.23', 
                        currency = 'PLN', ), 
                    bargain = allegro_api.models.badge_application_bargain_price.BadgeApplicationBargainPrice(
                        amount = '1.23', 
                        currency = 'PLN', ), ), 
                purchase_constraints = allegro_api.models.badge_application_purchase_constraints.BadgeApplicationPurchaseConstraints(
                    limit = allegro_api.models.badge_application_purchase_constraints_limit.BadgeApplicationPurchaseConstraintsLimit(
                        per_user = allegro_api.models.badge_application_purchase_constraints_limit_per_user.BadgeApplicationPurchaseConstraintsLimitPerUser(
                            max_items = 1, ), ), )
            )
        else :
            return BadgeApplicationRequest(
                campaign = allegro_api.models.badge_application_campaign.BadgeApplicationCampaign(
                    id = 'BARGAIN', ),
                offer = allegro_api.models.badge_offer.BadgeOffer(
                    id = '987654321', ),
        )

    def testBadgeApplicationRequest(self):
        """Test BadgeApplicationRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.information_about_user_api import InformationAboutUserApi  # noqa: E501
from allegro_api.rest import ApiException


class TestInformationAboutUserApi(unittest.TestCase):
    """InformationAboutUserApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.information_about_user_api.InformationAboutUserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_additional_email_using_post(self):
        """Test case for add_additional_email_using_post

        Add a new additional email address to user's account  # noqa: E501
        """
        pass

    def test_answer_user_rating_using_put(self):
        """Test case for answer_user_rating_using_put

        Answer for user's rating  # noqa: E501
        """
        pass

    def test_delete_additional_email_using_delete(self):
        """Test case for delete_additional_email_using_delete

        Delete an additional email address  # noqa: E501
        """
        pass

    def test_get_additional_email_using_get(self):
        """Test case for get_additional_email_using_get

        Get information about a particular additional email  # noqa: E501
        """
        pass

    def test_get_list_of_additional_emails_using_get(self):
        """Test case for get_list_of_additional_emails_using_get

        Get user's additional emails  # noqa: E501
        """
        pass

    def test_get_user_ratings_using_get(self):
        """Test case for get_user_ratings_using_get

        Get the user's ratings  # noqa: E501
        """
        pass

    def test_me_get(self):
        """Test case for me_get

        Get basic information about user  # noqa: E501
        """
        pass

    def test_user_rating_removal_using_put(self):
        """Test case for user_rating_removal_using_put

        Request removal of user's rating  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.after_sale_services_api import AfterSaleServicesApi  # noqa: E501
from allegro_api.rest import ApiException


class TestAfterSaleServicesApi(unittest.TestCase):
    """AfterSaleServicesApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.after_sale_services_api.AfterSaleServicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_public_seller_listing_using_get(self):
        """Test case for get_public_seller_listing_using_get

        Get the user's implied warranties  # noqa: E501
        """
        pass

    def test_get_public_seller_listing_using_get1(self):
        """Test case for get_public_seller_listing_using_get1

        Get the user's return policies  # noqa: E501
        """
        pass

    def test_get_public_seller_listing_using_get2(self):
        """Test case for get_public_seller_listing_using_get2

        Get the user's warranties  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ListingResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items': 'ListingResponseOffers',
        'categories': 'ListingResponseCategories',
        'filters': 'list[ListingResponseFilters]',
        'search_meta': 'ListingResponseSearchMeta',
        'sort': 'list[ListingResponseSort]'
    }

    attribute_map = {
        'items': 'items',
        'categories': 'categories',
        'filters': 'filters',
        'search_meta': 'searchMeta',
        'sort': 'sort'
    }

    def __init__(self, items=None, categories=None, filters=None, search_meta=None, sort=None, local_vars_configuration=None):  # noqa: E501
        """ListingResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items = None
        self._categories = None
        self._filters = None
        self._search_meta = None
        self._sort = None
        self.discriminator = None

        if items is not None:
            self.items = items
        if categories is not None:
            self.categories = categories
        if filters is not None:
            self.filters = filters
        if search_meta is not None:
            self.search_meta = search_meta
        if sort is not None:
            self.sort = sort

    @property
    def items(self):
        """Gets the items of this ListingResponse.  # noqa: E501


        :return: The items of this ListingResponse.  # noqa: E501
        :rtype: ListingResponseOffers
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ListingResponse.


        :param items: The items of this ListingResponse.  # noqa: E501
        :type: ListingResponseOffers
        """

        self._items = items

    @property
    def categories(self):
        """Gets the categories of this ListingResponse.  # noqa: E501


        :return: The categories of this ListingResponse.  # noqa: E501
        :rtype: ListingResponseCategories
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ListingResponse.


        :param categories: The categories of this ListingResponse.  # noqa: E501
        :type: ListingResponseCategories
        """

        self._categories = categories

    @property
    def filters(self):
        """Gets the filters of this ListingResponse.  # noqa: E501

        An array of filters with counters available for given search. This can be used to refine the search results.  # noqa: E501

        :return: The filters of this ListingResponse.  # noqa: E501
        :rtype: list[ListingResponseFilters]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this ListingResponse.

        An array of filters with counters available for given search. This can be used to refine the search results.  # noqa: E501

        :param filters: The filters of this ListingResponse.  # noqa: E501
        :type: list[ListingResponseFilters]
        """

        self._filters = filters

    @property
    def search_meta(self):
        """Gets the search_meta of this ListingResponse.  # noqa: E501


        :return: The search_meta of this ListingResponse.  # noqa: E501
        :rtype: ListingResponseSearchMeta
        """
        return self._search_meta

    @search_meta.setter
    def search_meta(self, search_meta):
        """Sets the search_meta of this ListingResponse.


        :param search_meta: The search_meta of this ListingResponse.  # noqa: E501
        :type: ListingResponseSearchMeta
        """

        self._search_meta = search_meta

    @property
    def sort(self):
        """Gets the sort of this ListingResponse.  # noqa: E501

        Available sorting options.  # noqa: E501

        :return: The sort of this ListingResponse.  # noqa: E501
        :rtype: list[ListingResponseSort]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this ListingResponse.

        Available sorting options.  # noqa: E501

        :param sort: The sort of this ListingResponse.  # noqa: E501
        :type: list[ListingResponseSort]
        """

        self._sort = sort

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListingResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListingResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OfferSellingMode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'format': 'SellingModeFormat',
        'price': 'OfferPrice',
        'fixed_price': 'OfferFixedPrice',
        'popularity': 'int',
        'bid_count': 'int'
    }

    attribute_map = {
        'format': 'format',
        'price': 'price',
        'fixed_price': 'fixedPrice',
        'popularity': 'popularity',
        'bid_count': 'bidCount'
    }

    def __init__(self, format=None, price=None, fixed_price=None, popularity=None, bid_count=None, local_vars_configuration=None):  # noqa: E501
        """OfferSellingMode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._format = None
        self._price = None
        self._fixed_price = None
        self._popularity = None
        self._bid_count = None
        self.discriminator = None

        if format is not None:
            self.format = format
        if price is not None:
            self.price = price
        if fixed_price is not None:
            self.fixed_price = fixed_price
        if popularity is not None:
            self.popularity = popularity
        if bid_count is not None:
            self.bid_count = bid_count

    @property
    def format(self):
        """Gets the format of this OfferSellingMode.  # noqa: E501


        :return: The format of this OfferSellingMode.  # noqa: E501
        :rtype: SellingModeFormat
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this OfferSellingMode.


        :param format: The format of this OfferSellingMode.  # noqa: E501
        :type: SellingModeFormat
        """

        self._format = format

    @property
    def price(self):
        """Gets the price of this OfferSellingMode.  # noqa: E501


        :return: The price of this OfferSellingMode.  # noqa: E501
        :rtype: OfferPrice
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this OfferSellingMode.


        :param price: The price of this OfferSellingMode.  # noqa: E501
        :type: OfferPrice
        """

        self._price = price

    @property
    def fixed_price(self):
        """Gets the fixed_price of this OfferSellingMode.  # noqa: E501


        :return: The fixed_price of this OfferSellingMode.  # noqa: E501
        :rtype: OfferFixedPrice
        """
        return self._fixed_price

    @fixed_price.setter
    def fixed_price(self, fixed_price):
        """Sets the fixed_price of this OfferSellingMode.


        :param fixed_price: The fixed_price of this OfferSellingMode.  # noqa: E501
        :type: OfferFixedPrice
        """

        self._fixed_price = fixed_price

    @property
    def popularity(self):
        """Gets the popularity of this OfferSellingMode.  # noqa: E501

        Popularity of the offer for *BUY_NOW* selling format.  # noqa: E501

        :return: The popularity of this OfferSellingMode.  # noqa: E501
        :rtype: int
        """
        return self._popularity

    @popularity.setter
    def popularity(self, popularity):
        """Sets the popularity of this OfferSellingMode.

        Popularity of the offer for *BUY_NOW* selling format.  # noqa: E501

        :param popularity: The popularity of this OfferSellingMode.  # noqa: E501
        :type: int
        """

        self._popularity = popularity

    @property
    def bid_count(self):
        """Gets the bid_count of this OfferSellingMode.  # noqa: E501

        Number of bidders for *AUCTION* selling format.  # noqa: E501

        :return: The bid_count of this OfferSellingMode.  # noqa: E501
        :rtype: int
        """
        return self._bid_count

    @bid_count.setter
    def bid_count(self, bid_count):
        """Sets the bid_count of this OfferSellingMode.

        Number of bidders for *AUCTION* selling format.  # noqa: E501

        :param bid_count: The bid_count of this OfferSellingMode.  # noqa: E501
        :type: int
        """

        self._bid_count = bid_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfferSellingMode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OfferSellingMode):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CheckoutFormDeliveryAddress(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'first_name': 'str',
        'last_name': 'str',
        'street': 'str',
        'city': 'str',
        'zip_code': 'str',
        'country_code': 'str',
        'company_name': 'str',
        'phone_number': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'street': 'street',
        'city': 'city',
        'zip_code': 'zipCode',
        'country_code': 'countryCode',
        'company_name': 'companyName',
        'phone_number': 'phoneNumber'
    }

    def __init__(self, first_name=None, last_name=None, street=None, city=None, zip_code=None, country_code=None, company_name=None, phone_number=None, local_vars_configuration=None):  # noqa: E501
        """CheckoutFormDeliveryAddress - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._first_name = None
        self._last_name = None
        self._street = None
        self._city = None
        self._zip_code = None
        self._country_code = None
        self._company_name = None
        self._phone_number = None
        self.discriminator = None

        self.first_name = first_name
        self.last_name = last_name
        self.street = street
        self.city = city
        self.zip_code = zip_code
        self.country_code = country_code
        if company_name is not None:
            self.company_name = company_name
        if phone_number is not None:
            self.phone_number = phone_number

    @property
    def first_name(self):
        """Gets the first_name of this CheckoutFormDeliveryAddress.  # noqa: E501

        Receiver's first name  # noqa: E501

        :return: The first_name of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this CheckoutFormDeliveryAddress.

        Receiver's first name  # noqa: E501

        :param first_name: The first_name of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and first_name is None:  # noqa: E501
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this CheckoutFormDeliveryAddress.  # noqa: E501

        Receiver's last name  # noqa: E501

        :return: The last_name of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this CheckoutFormDeliveryAddress.

        Receiver's last name  # noqa: E501

        :param last_name: The last_name of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and last_name is None:  # noqa: E501
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def street(self):
        """Gets the street of this CheckoutFormDeliveryAddress.  # noqa: E501

        Street name  # noqa: E501

        :return: The street of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this CheckoutFormDeliveryAddress.

        Street name  # noqa: E501

        :param street: The street of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and street is None:  # noqa: E501
            raise ValueError("Invalid value for `street`, must not be `None`")  # noqa: E501

        self._street = street

    @property
    def city(self):
        """Gets the city of this CheckoutFormDeliveryAddress.  # noqa: E501

        City name  # noqa: E501

        :return: The city of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this CheckoutFormDeliveryAddress.

        City name  # noqa: E501

        :param city: The city of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and city is None:  # noqa: E501
            raise ValueError("Invalid value for `city`, must not be `None`")  # noqa: E501

        self._city = city

    @property
    def zip_code(self):
        """Gets the zip_code of this CheckoutFormDeliveryAddress.  # noqa: E501

        Postal code  # noqa: E501

        :return: The zip_code of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """Sets the zip_code of this CheckoutFormDeliveryAddress.

        Postal code  # noqa: E501

        :param zip_code: The zip_code of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and zip_code is None:  # noqa: E501
            raise ValueError("Invalid value for `zip_code`, must not be `None`")  # noqa: E501

        self._zip_code = zip_code

    @property
    def country_code(self):
        """Gets the country_code of this CheckoutFormDeliveryAddress.  # noqa: E501

        Country code  # noqa: E501

        :return: The country_code of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this CheckoutFormDeliveryAddress.

        Country code  # noqa: E501

        :param country_code: The country_code of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and country_code is None:  # noqa: E501
            raise ValueError("Invalid value for `country_code`, must not be `None`")  # noqa: E501

        self._country_code = country_code

    @property
    def company_name(self):
        """Gets the company_name of this CheckoutFormDeliveryAddress.  # noqa: E501

        Company name  # noqa: E501

        :return: The company_name of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this CheckoutFormDeliveryAddress.

        Company name  # noqa: E501

        :param company_name: The company_name of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def phone_number(self):
        """Gets the phone_number of this CheckoutFormDeliveryAddress.  # noqa: E501

        Phone number  # noqa: E501

        :return: The phone_number of this CheckoutFormDeliveryAddress.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this CheckoutFormDeliveryAddress.

        Phone number  # noqa: E501

        :param phone_number: The phone_number of this CheckoutFormDeliveryAddress.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckoutFormDeliveryAddress):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckoutFormDeliveryAddress):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class PromotionCampaignsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_promotion_to_campaign_using_post(self, promotion_campaign_request_dto, **kwargs):  # noqa: E501
        """Create an application for a promotion campaign  # noqa: E501

        For an additional fee, you can place a discount mark on a list of offers.         You have to define promotion id and campaign section giving LISTING_BADGE as the id.         Your promotion campaign application will be verified and you will be notified about the verification status via e-mail.         Fees will be charged in accordance with Annex No. 1 to the Daily deals zone regulations.         <a href=\"../../offer_bundles/#11\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_promotion_to_campaign_using_post(promotion_campaign_request_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PromotionCampaignRequestDto promotion_campaign_request_dto: request (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PromotionCampaignResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_promotion_to_campaign_using_post_with_http_info(promotion_campaign_request_dto, **kwargs)  # noqa: E501

    def add_promotion_to_campaign_using_post_with_http_info(self, promotion_campaign_request_dto, **kwargs):  # noqa: E501
        """Create an application for a promotion campaign  # noqa: E501

        For an additional fee, you can place a discount mark on a list of offers.         You have to define promotion id and campaign section giving LISTING_BADGE as the id.         Your promotion campaign application will be verified and you will be notified about the verification status via e-mail.         Fees will be charged in accordance with Annex No. 1 to the Daily deals zone regulations.         <a href=\"../../offer_bundles/#11\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_promotion_to_campaign_using_post_with_http_info(promotion_campaign_request_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PromotionCampaignRequestDto promotion_campaign_request_dto: request (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PromotionCampaignResponseDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['promotion_campaign_request_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_promotion_to_campaign_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'promotion_campaign_request_dto' is set
        if self.api_client.client_side_validation and ('promotion_campaign_request_dto' not in local_var_params or  # noqa: E501
                                                        local_var_params['promotion_campaign_request_dto'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `promotion_campaign_request_dto` when calling `add_promotion_to_campaign_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'promotion_campaign_request_dto' in local_var_params:
            body_params = local_var_params['promotion_campaign_request_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotion-campaigns', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PromotionCampaignResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_campaign_from_promotion_using_delete(self, promotion_id, campaign_id, **kwargs):  # noqa: E501
        """Delete a campaign in a promotion  # noqa: E501

        Use this resource to delete campaign from promotion by promotion id and campaign id. <a href=\"../../offer_bundles/#16\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_campaign_from_promotion_using_delete(promotion_id, campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: The promotion unique id. (required)
        :param str campaign_id: The campaign unique id. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_campaign_from_promotion_using_delete_with_http_info(promotion_id, campaign_id, **kwargs)  # noqa: E501

    def delete_campaign_from_promotion_using_delete_with_http_info(self, promotion_id, campaign_id, **kwargs):  # noqa: E501
        """Delete a campaign in a promotion  # noqa: E501

        Use this resource to delete campaign from promotion by promotion id and campaign id. <a href=\"../../offer_bundles/#16\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_campaign_from_promotion_using_delete_with_http_info(promotion_id, campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: The promotion unique id. (required)
        :param str campaign_id: The campaign unique id. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['promotion_id', 'campaign_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_campaign_from_promotion_using_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'promotion_id' is set
        if self.api_client.client_side_validation and ('promotion_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['promotion_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `promotion_id` when calling `delete_campaign_from_promotion_using_delete`")  # noqa: E501
        # verify the required parameter 'campaign_id' is set
        if self.api_client.client_side_validation and ('campaign_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['campaign_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `campaign_id` when calling `delete_campaign_from_promotion_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'promotion_id' in local_var_params and local_var_params['promotion_id'] is not None:  # noqa: E501
            query_params.append(('promotion.id', local_var_params['promotion_id']))  # noqa: E501
        if 'campaign_id' in local_var_params and local_var_params['campaign_id'] is not None:  # noqa: E501
            query_params.append(('campaign.id', local_var_params['campaign_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotion-campaigns', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_promotion_campaign_application_using_delete(self, application_id, **kwargs):  # noqa: E501
        """Delete an application for promotion campaign  # noqa: E501

        Use this resource to delete promotion campaign application by application id. You need to use its unique id. <a href=\"../../offer_bundles/#15\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_promotion_campaign_application_using_delete(application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str application_id: The application unique id. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_promotion_campaign_application_using_delete_with_http_info(application_id, **kwargs)  # noqa: E501

    def delete_promotion_campaign_application_using_delete_with_http_info(self, application_id, **kwargs):  # noqa: E501
        """Delete an application for promotion campaign  # noqa: E501

        Use this resource to delete promotion campaign application by application id. You need to use its unique id. <a href=\"../../offer_bundles/#15\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_promotion_campaign_application_using_delete_with_http_info(application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str application_id: The application unique id. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['application_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_promotion_campaign_application_using_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'application_id' is set
        if self.api_client.client_side_validation and ('application_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['application_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_id` when calling `delete_promotion_campaign_application_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application_id' in local_var_params:
            path_params['applicationId'] = local_var_params['application_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotion-campaign-applications/{applicationId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_promotion_campaign_application_using_get(self, application_id, **kwargs):  # noqa: E501
        """Get an application for promotion campaign  # noqa: E501

        Use this resource to retrieve promotion campaign application. You need to use its unique id. <a href=\"../../offer_bundles/#12\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_promotion_campaign_application_using_get(application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str application_id: The application unique id. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_promotion_campaign_application_using_get_with_http_info(application_id, **kwargs)  # noqa: E501

    def get_promotion_campaign_application_using_get_with_http_info(self, application_id, **kwargs):  # noqa: E501
        """Get an application for promotion campaign  # noqa: E501

        Use this resource to retrieve promotion campaign application. You need to use its unique id. <a href=\"../../offer_bundles/#12\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_promotion_campaign_application_using_get_with_http_info(application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str application_id: The application unique id. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['application_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_promotion_campaign_application_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'application_id' is set
        if self.api_client.client_side_validation and ('application_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['application_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_id` when calling `get_promotion_campaign_application_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application_id' in local_var_params:
            path_params['applicationId'] = local_var_params['application_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotion-campaign-applications/{applicationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_promotion_campaigns_using_get(self, **kwargs):  # noqa: E501
        """Get the user's promotion campaigns  # noqa: E501

        Use this resource to retrieve promotion campaigns. You can find promotion campaign by promotion id. <a href=\"../../offer_bundles/#13\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_promotion_campaigns_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: The promotion unique id.
        :param int limit: The limit of elements in the response.
        :param int offset: The offset of elements in the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PromotionCampaignsResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_promotion_campaigns_using_get_with_http_info(**kwargs)  # noqa: E501

    def get_promotion_campaigns_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get the user's promotion campaigns  # noqa: E501

        Use this resource to retrieve promotion campaigns. You can find promotion campaign by promotion id. <a href=\"../../offer_bundles/#13\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_promotion_campaigns_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: The promotion unique id.
        :param int limit: The limit of elements in the response.
        :param int offset: The offset of elements in the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PromotionCampaignsResponseDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['promotion_id', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_promotion_campaigns_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'promotion_id' in local_var_params and local_var_params['promotion_id'] is not None:  # noqa: E501
            query_params.append(('promotion.id', local_var_params['promotion_id']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotion-campaigns', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PromotionCampaignsResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
